@@ -1,6 +1,6 @@
 # uWSGI build system
 
-uwsgi_version = '2.0.24'
+uwsgi_version = '2.0.26'
 
 import os
 import re
@@ -690,8 +690,6 @@ class uConf(object):
             '-D_LARGEFILE_SOURCE',
             '-D_FILE_OFFSET_BITS=64'
         ]
-        if "gcc" in GCC:
-            cflags.append('-Wformat-signedness')
         self.cflags = cflags + os.environ.get("CFLAGS", "").split() + self.get('cflags', '').split()
 
         report['kernel'] = uwsgi_os
@@ -710,13 +708,13 @@ class uConf(object):
         if uwsgi_os == 'GNU':
             self.cflags.append('-D__HURD__')
 
-        gcc_version = spcall("%s -dumpversion" % GCC)
+        gcc_version = spcall("%s -dumpfullversion -dumpversion" % GCC)
         if not gcc_version and GCC.startswith('gcc'):
             if uwsgi_os == 'Darwin':
                 GCC = 'llvm-' + GCC
             else:
                 GCC = 'gcc'
-            gcc_version = spcall("%s -dumpversion" % GCC)
+            gcc_version = spcall("%s -dumpfullversion -dumpversion" % GCC)
 
         try:
             add_it = False
@@ -767,6 +765,8 @@ class uConf(object):
             self.cflags = self.cflags + [ '-Wextra', '-Wno-unused-parameter', '-Wno-missing-field-initializers' ]
         if gcc_major == 4 and gcc_minor < 9:
             self.cflags.append('-Wno-format -Wno-format-security')
+        if "gcc" in GCC and gcc_major >= 5:
+            self.cflags.append('-Wformat-signedness')
 
         self.ldflags = os.environ.get("LDFLAGS", "").split()
         self.libs = ['-lpthread', '-lm', '-rdynamic']
@@ -1083,30 +1083,30 @@ class uConf(object):
 
         has_pcre = False
 
-        # re-enable after pcre fix
-        if self.get('pcre'):
-            if self.get('pcre') == 'auto':
-                pcreconf = spcall('pcre-config --libs')
-                if pcreconf:
-                    self.libs.append(pcreconf)
-                    pcreconf = spcall("pcre-config --cflags")
-                    self.cflags.append(pcreconf)
-                    self.gcc_list.append('core/regexp')
-                    self.cflags.append("-DUWSGI_PCRE")
-                    has_pcre = True
-
+        required_pcre = self.get('pcre')
+        if required_pcre:
+            pcre_libs = spcall('pcre2-config --libs8')
+            if pcre_libs:
+                pcre_cflags = spcall("pcre2-config --cflags")
+                pcre_define = "-DUWSGI_PCRE2"
             else:
-                pcreconf = spcall('pcre-config --libs')
-                if pcreconf is None:
-                    print("*** libpcre headers unavailable. uWSGI build is interrupted. You have to install pcre development package or disable pcre")
-                    sys.exit(1)
-                else:
-                    self.libs.append(pcreconf)
-                    pcreconf = spcall("pcre-config --cflags")
-                    self.cflags.append(pcreconf)
-                    self.gcc_list.append('core/regexp')
-                    self.cflags.append("-DUWSGI_PCRE")
-                    has_pcre = True
+                pcre_libs = spcall('pcre-config --libs')
+                pcre_cflags = spcall("pcre-config --cflags")
+                pcre_define = "-DUWSGI_PCRE"
+        else:
+            pcre_libs = None
+
+        if required_pcre:
+            if required_pcre != 'auto' and pcre_libs is None:
+                print("*** libpcre headers unavailable. uWSGI build is interrupted. You have to install pcre development package or disable pcre")
+                sys.exit(1)
+
+            if pcre_libs:
+                self.libs.append(pcre_libs)
+                self.cflags.append(pcre_cflags)
+                self.gcc_list.append('core/regexp')
+                self.cflags.append(pcre_define)
+                has_pcre = True
 
         if has_pcre:
             report['pcre'] = True
